@@ -1,5 +1,8 @@
 import abc
-from typing import List, Generator, Tuple
+import os
+import shutil
+
+from typing import List, Generator, Tuple, Sequence
 
 from pydmt.utils.digester import Digester
 
@@ -17,6 +20,10 @@ class Node(abc.ABC):
     def get_name(self) -> str:
         pass
 
+    @abc.abstractmethod
+    def remove(self) -> None:
+        pass
+
 
 class Builder(abc.ABC):
     """
@@ -51,7 +58,7 @@ class Builder(abc.ABC):
         """
 
     @abc.abstractmethod
-    def get_sources(self) -> List[Node]:
+    def get_sources(self) -> Sequence[Node]:
         """
         return the name of the source files for this builder
         If the builder takes a whole folder the list all the filers in that folder.
@@ -62,7 +69,7 @@ class Builder(abc.ABC):
         In the future the get_signature method will go away.
         """
     @abc.abstractmethod
-    def get_targets(self) -> List[Node]:
+    def get_targets(self) -> Sequence[Node]:
         """
         return list of targets
         """
@@ -102,6 +109,9 @@ class File(Node):
     def get_name(self):
         return self.filename
 
+    def remove(self):
+        os.unlink(self.filename)
+
 
 class SourceFile(File):
     pass
@@ -125,6 +135,10 @@ class SourceFiles(Node):
     def get_name(self):
         return self.name
 
+    def remove(self):
+        for filename in self.filenames:
+            os.unlink(filename)
+
 
 class Folder(Node):
     """
@@ -139,6 +153,9 @@ class Folder(Node):
     def get_name(self):
         return self.folder
 
+    def remove(self):
+        shutil.rmtree(self.folder)
+
 
 class SourceFolder(Folder):
     pass
